==> aws-cdk.aws-elasticloadbalancingv2-1.40.0.tar.gz: package/test/alb/test.listener.d.ts <==
import { Test } from 'nodeunit';
declare const _default: {
    'Listener guesses protocol from port'(test: Test): void;
    'Listener guesses port from protocol'(test: Test): void;
    'Listener default to open'(test: Test): void;
    'HTTPS listener requires certificate'(test: Test): void;
    'HTTPS listener can add certificate after construction'(test: Test): void;
    'Can configure targetType on TargetGroups'(test: Test): void;
    'Can configure name on TargetGroups'(test: Test): void;
    'Can add target groups with and without conditions'(test: Test): void;
    'Can implicitly create target groups with and without conditions'(test: Test): void;
    'Add certificate to constructed listener'(test: Test): void;
    'Add certificate to imported listener'(test: Test): void;
    'Enable stickiness for targets'(test: Test): void;
    'Enable health check for targets'(test: Test): void;
    'validation error if invalid health check protocol'(test: Test): void;
    'Can call addTargetGroups on imported listener'(test: Test): void;
    'Can depend on eventual listener via TargetGroup'(test: Test): void;
    'Exercise metrics'(test: Test): void;
    'Can add dependency on ListenerRule via TargetGroup'(test: Test): void;
    'Can add fixed responses'(test: Test): void;
    'Can add redirect responses'(test: Test): void;
    'Can configure deregistration_delay for targets'(test: Test): void;
    'Throws with bad fixed responses': {
        'status code'(test: Test): void;
        'message body'(test: Test): void;
    };
    'Throws with bad redirect responses': {
        'status code'(test: Test): void;
        protocol(test: Test): void;
    };
    'Throws when specifying both target groups and fixed reponse'(test: Test): void;
    'Throws when specifying priority 0'(test: Test): void;
    'Throws when specifying both target groups and redirect reponse'(test: Test): void;
    'Imported listener with imported security group and allowAllOutbound set to false'(test: Test): void;
    'Can pass multiple certificate arns to application listener constructor'(test: Test): void;
    'Can use certificate wrapper class'(test: Test): void;
    'Can add additional certificates via addCertficateArns to application listener'(test: Test): void;
    'Can add multiple path patterns to listener rule'(test: Test): void;
    'Cannot add pathPattern and pathPatterns to listener rule'(test: Test): void;
    'Add path patterns to imported application listener'(test: Test): void;
    'not allowed to combine action specifiers when instantiating a Rule directly'(test: Test): void;
    'not allowed to specify defaultTargetGroups and defaultAction together'(test: Test): void;
};
export = _default;

==> aws-cdk.aws-elasticloadbalancingv2-1.48.0.tar.gz: package/test/alb/test.listener.d.ts <==
import { Test } from 'nodeunit';
declare const _default: {
    'Listener guesses protocol from port'(test: Test): void;
    'Listener guesses port from protocol'(test: Test): void;
    'Listener default to open'(test: Test): void;
    'HTTPS listener requires certificate'(test: Test): void;
    'HTTPS listener can add certificate after construction'(test: Test): void;
    'Can configure targetType on TargetGroups'(test: Test): void;
    'Can configure name on TargetGroups'(test: Test): void;
    'Can add target groups with and without conditions'(test: Test): void;
    'Can implicitly create target groups with and without conditions'(test: Test): void;
    'Add certificate to constructed listener'(test: Test): void;
    'Add certificate to imported listener'(test: Test): void;
    'Enable stickiness for targets'(test: Test): void;
    'Enable health check for targets'(test: Test): void;
    'validation error if invalid health check protocol'(test: Test): void;
    'Can call addTargetGroups on imported listener'(test: Test): void;
    'Can depend on eventual listener via TargetGroup'(test: Test): void;
    'Exercise metrics'(test: Test): void;
    'Can add dependency on ListenerRule via TargetGroup'(test: Test): void;
    'Can add fixed responses'(test: Test): void;
    'Can add redirect responses'(test: Test): void;
    'Can configure deregistration_delay for targets'(test: Test): void;
    'Throws with bad fixed responses': {
        'status code'(test: Test): void;
        'message body'(test: Test): void;
    };
    'Throws with bad redirect responses': {
        'status code'(test: Test): void;
        protocol(test: Test): void;
    };
    'Throws when specifying both target groups and fixed reponse'(test: Test): void;
    'Throws when specifying priority 0'(test: Test): void;
    'Throws when specifying both target groups and redirect reponse'(test: Test): void;
    'Imported listener with imported security group and allowAllOutbound set to false'(test: Test): void;
    'Can pass multiple certificate arns to application listener constructor'(test: Test): void;
    'Can use certificate wrapper class'(test: Test): void;
    'Can add additional certificates via addCertficateArns to application listener'(test: Test): void;
    'Can add multiple path patterns to listener rule'(test: Test): void;
    'Cannot add pathPattern and pathPatterns to listener rule'(test: Test): void;
    'Add additonal condition to listener rule'(test: Test): void;
    'Add multiple additonal condition to listener rule'(test: Test): void;
    'Can exist together legacy style conditions and modan style conditions'(test: Test): void;
    'Add condition to imported application listener'(test: Test): void;
    'not allowed to combine action specifiers when instantiating a Rule directly'(test: Test): void;
    'not allowed to specify defaultTargetGroups and defaultAction together'(test: Test): void;
};
export = _default;
